Attributes

Type Alias Attributes 

pub type Attributes<'a> = HashMap<&'a str, &'a str>;
Represents the attributes in a HTML Element.

Attributes are all the parameters that are not tags. For example, using the styles attribute could be used to change the css in a given Element.

Aliased Type

pub struct Attributes<'a> { /* private fields */ }